@@ -226,35 +226,39 @@ ESExpResult *func_geometry(ESExp *f, int argc, ESExpResult **argv, Context *c) {
  * Center position of current window.
  */
 ESExpResult *func_center(ESExp *f, int argc, ESExpResult **argv, Context *c) {
-  gint xoffset, yoffset, window_width, window_height,
-    workspace_width, workspace_height;
-  int new_xoffset, new_yoffset;
-
-  /* read in window geometry */
-  wnck_window_get_geometry (c->window,
-                            &xoffset, &yoffset, &window_width, &window_height);
-
-  /* read in workspace geometry */
+  int xoffset, yoffset, window_width, window_height, workspace_width, workspace_height;
   WnckScreen *screen;
   WnckWorkspace *workspace;
-  screen           = wnck_window_get_screen (c->window);
-  workspace        = wnck_screen_get_active_workspace (screen);
-  workspace_width  = wnck_workspace_get_width  (workspace);
+
+  /* Read in window geometry */
+  wnck_window_get_geometry (c->window, NULL, NULL, &window_width, &window_height);
+
+  /* Read in workspace geometry */
+  screen = wnck_window_get_screen (c->window);
+  
+  workspace = wnck_screen_get_active_workspace (screen);
+  if (workspace == NULL)
+    workspace = wnck_screen_get_workspace (screen, 0);
+  if (workspace == NULL) {
+    g_printerr (_("Cannot get workspace\n"));
+    return e_sexp_result_new_bool (f, FALSE);
+  }
+
+  workspace_width = wnck_workspace_get_width (workspace);
   workspace_height = wnck_workspace_get_height (workspace);
 
-  /* calculate offset for upper left corner */
-  new_xoffset = (workspace_width - window_width) / 2;
-  new_yoffset = (workspace_height - window_height) / 2;
+  /* Calculate offset for upper left corner */
+  xoffset = (workspace_width - window_width) / 2;
+  yoffset = (workspace_height - window_height) / 2;
 
-  /* try to set new position.. */
+  /* Try to set new position.. */
   my_wnck_error_trap_push ();
   XMoveWindow (gdk_display,
                wnck_window_get_xid (c->window),
-               new_xoffset, new_yoffset);
+               xoffset, yoffset);
 
   if (my_wnck_error_trap_pop ()) {
-    g_printerr (_("Centering '%s' failed\n"),
-               argv[0]->value.string);
+    g_printerr (_("Centering '%s' failed\n"), argv[0]->value.string);
     return e_sexp_result_new_bool (f, FALSE);
   }
 
@@ -438,6 +442,36 @@ ESExpResult *func_set_workspace(ESExp *f, int argc, ESExpResult **argv, Context
   return e_sexp_result_new_bool (f, TRUE);
 }
 
+/**
+ * Change current workspace, counting from 1
+ */
+ESExpResult *func_change_workspace(ESExp *f, int argc, ESExpResult **argv, Context *c) {
+  WnckScreen *screen;
+  WnckWorkspace *workspace;
+  int num;
+  GTimeVal timestamp;
+
+  if (argc != 1 || argv[0]->type != ESEXP_RES_INT) {
+    g_printerr(_("change_workspace expects a single integer argument\n"));
+    return e_sexp_result_new_bool (f, FALSE);
+  }
+
+  num = argv[0]->value.number;
+
+  screen = wnck_window_get_screen(c->window);
+  /* Adjust for 0-offset in workspaces list */
+  workspace = wnck_screen_get_workspace(screen, num-1);
+  if (!workspace) {
+    g_warning(_("Workspace number %d does not exist"), num);
+    return e_sexp_result_new_bool (f, FALSE);
+  }
+  g_get_current_time(&timestamp);
+  wnck_workspace_activate(workspace, timestamp.tv_sec);
+
+  if (debug) g_printerr(_("Switching workspace to %d\n"), num);
+  return e_sexp_result_new_bool (f, TRUE);
+}
+
 /**
  * Move the window to a specific viewport number, counting from 1.
  */
@@ -526,10 +560,9 @@ ESExpResult *func_below(ESExp *f, int argc, ESExpResult **argv, Context *c) {
   return e_sexp_result_new_bool (f, TRUE);
 }
 
-/**
- * Remove the window manager decorations from the current window.
- */
-ESExpResult *func_undecorate(ESExp *f, int argc, ESExpResult **argv, Context *c) {
+static void
+set_decorations (Context *c, gboolean decorate)
+{
 #define PROP_MOTIF_WM_HINTS_ELEMENTS 5
 #define MWM_HINTS_DECORATIONS (1L << 1)
   struct {
@@ -541,10 +574,8 @@ ESExpResult *func_undecorate(ESExp *f, int argc, ESExpResult **argv, Context *c)
   } hints = {0,};
 
   hints.flags = MWM_HINTS_DECORATIONS;
-  hints.decorations = 0;
+  hints.decorations = decorate ? 1 : 0;
 
-  my_wnck_error_trap_push ();
-  
   /* Set Motif hints, most window managers handle these */
   XChangeProperty(GDK_DISPLAY(), wnck_window_get_xid (c->window),
                   my_wnck_atom_get ("_MOTIF_WM_HINTS"), 
@@ -554,9 +585,19 @@ ESExpResult *func_undecorate(ESExp *f, int argc, ESExpResult **argv, Context *c)
   /* Apart from OpenBox, which doesn't respect it changing after mapping.
      Instead it has this workaround. */
   my_wnck_change_state (my_wnck_window_get_xscreen(c->window),
-                        wnck_window_get_xid(c->window), TRUE,
+                        wnck_window_get_xid(c->window), decorate,
                         my_wnck_atom_get ("_OB_WM_STATE_UNDECORATED"), 0);
 
+}
+
+/**
+ * Remove the window manager decorations from the current window.
+ */
+ESExpResult *func_undecorate(ESExp *f, int argc, ESExpResult **argv, Context *c) {
+  my_wnck_error_trap_push ();
+
+  set_decorations (c, FALSE);
+
   if (my_wnck_error_trap_pop () != 0) {
     g_printerr(_("Removing decorations failed"));
     return e_sexp_result_new_bool (f, FALSE);
@@ -566,6 +607,24 @@ ESExpResult *func_undecorate(ESExp *f, int argc, ESExpResult **argv, Context *c)
   return e_sexp_result_new_bool (f, TRUE);
 }
 
+
+/**
+ * Add the window manager decorations to the current window.
+ */
+ESExpResult *func_decorate(ESExp *f, int argc, ESExpResult **argv, Context *c) {
+  my_wnck_error_trap_push ();
+  
+  set_decorations (c, TRUE);
+
+  if (my_wnck_error_trap_pop () != 0) {
+    g_printerr(_("Adding decorations failed"));
+    return e_sexp_result_new_bool (f, FALSE);
+  }
+
+  if (debug) g_printerr(_("Added decorations\n"));
+  return e_sexp_result_new_bool (f, TRUE);
+}
+
 /**
  * Set the window type of the current window.
  *
@@ -768,3 +827,12 @@ ESExpResult *func_spawn_async(ESExp *f, int argc, ESExpResult **argv, Context *c
   
   return e_sexp_result_new_bool (f, spawn_result);
 }
+
+/**
+ * Quit
+ */
+ESExpResult *func_quit(ESExp *f, int argc, ESExpResult **argv, Context *c) {
+  g_main_loop_quit (loop);
+  if (debug) g_printerr(_("Quiting...\n"));
+  return e_sexp_result_new_bool (f, TRUE);
+}
